# This script will read in BAMM eventdata, then subset event data based on 10%, 30%, 50% non-tropical species removal
# then check if the tip rates were influenced by the reduction of numbers in non-tropical species
# most of event data generated by BAMM from 17 roders are large GB-size file, therefore not include here

#clean env
rm(list=ls())

#loading packages
library("phytools")
library("ape")
library("BAMMtools")
library("geiger") # For drop.tips
library("dplyr")

########laodong env data###########
#loading mean annual Tm
An_Tm <- read.csv("./Datasets/Temperature_Data_Layers/Rosid_Annual_Tm_mean.csv", header=TRUE)
An_Tm.vector <-  as.numeric(An_Tm$Tm.mean)
names(An_Tm.vector) <- An_Tm$Species


#loading Koeppen-Geiger tropical data
Trop.Koep <- read.csv("./Datasets/Temperature_Data_Layers/Rosid_Climatic_Tropics_binary.csv", header = TRUE)
Trop.Koep.vector <-  as.numeric(Trop.Koep$Tropical)
names(Trop.Koep.vector) <- Trop.Koep$Species

#loading Latitudinal tropical data
Trop.Geo <- read.csv("./Datasets/Temperature_Data_Layers/Rosid_Geographic_Tropics_binary.csv", header = TRUE)
Trop.Geo.vector <-  as.numeric(Trop.Geo$T.binary)
names(Trop.Geo.vector) <- Trop.Geo$Species

#basic function trying to random dropping tmeperate species test 
# then summarize rates and p.values of each traits
strapp_drop_tip_test <- function(clade){
  
  tryCatch({
    
    # print(clade)
    
    tree <- read.tree(paste0("path/to/BAMM_data/5g/", clade, "/", clade, ".tre", sep=""))
    
    # then laoding eventdata by each clade
    edata <- getEventData(tree, paste0("path/to//BAMM_data/5g/", clade, "/", clade, "_event_data_final.txt",  sep=""), burnin = 0.8)
    edata$tip.label <- sub("^.(.*)ceae_", "", edata$tip.label)
    tree$tip.label <- sub("^.(.*)ceae_", "", tree$tip.label)
    
    # get mean median speciation rates for each order
    tip_rates <- getTipRates(edata, returnNetDiv = FALSE, statistic = 'median')$lambda.avg

    Tmean <- mean(tip_rates)
     
    ################################################
    
    #Koeppen-Geiger tropical data
    trait.vector <-  treedata(tree, Trop.Koep.vector)$data
    K.data <- cbind.data.frame(Species=row.names(trait.vector), Tropicality=as.numeric(trait.vector[,1]))
    
    #drop temperate species 10%, 30% and 50%
     for(i in c(0.1, 0.3, 0.5)){
       
       treatment <- paste0(i*100, "% drop")
    
       drop_tips <- K.data %>% filter(Tropicality==0) %>% select(Species) %>% sample_frac(as.numeric(i))
       keep.tips <- setdiff(K.data$Species, drop_tips$Species)
       edata.sub <- subtreeBAMM(edata, tips = keep.tips)
    
       tip_rates.sub <- getTipRates(edata.sub, returnNetDiv = FALSE, statistic = 'median')$lambda.avg
       Tmean.sub <- mean(tip_rates.sub)
    
       trait.vector.sub <- trait.vector[setdiff(as.character(K.data$Species), as.character(drop_tips$Species)),]
    
       Corr_Koep_Rate <- traitDependentBAMM(edata.sub, trait.vector.sub, 1000, return.full = FALSE, method = "mann-whitney", logrates = TRUE, two.tailed = TRUE, traitorder = NA)
       
       cat(paste0(clade,",", Tmean, ",", treatment, ",", Tmean.sub, ",", Corr_Koep_Rate$estimate$`1`, ",", Corr_Koep_Rate$estimate$`0`, ",", Corr_Koep_Rate$p.value, sep=""), file=file1, sep="\n", append = T   )
     }
    
    ################################################
    
    # #Latitudinal tropical data
    trait.vector2 <-  treedata(tree, Trop.Geo.vector)$data
    G.data <- cbind.data.frame(Species=row.names(trait.vector2), Tropicality=as.numeric(trait.vector2[,1]))
    
    #drop temperate species 10%, 30% and 50%
    for(i in c(0.1, 0.3, 0.5)){
      
      treatment <- paste0(i*100, "% drop")
      
      drop_tips <- G.data %>% filter(Tropicality==0) %>% select(Species) %>% sample_frac(as.numeric(i))
      keep.tips <- setdiff(G.data$Species, drop_tips$Species)
      edata.sub <- subtreeBAMM(edata, tips = keep.tips)
      
      tip_rates.sub <- getTipRates(edata.sub, returnNetDiv = FALSE, statistic = 'median')$lambda.avg
      Tmean.sub <- mean(tip_rates.sub)
      
      trait.vector.sub <- trait.vector2[keep.tips,]
      
      Corr_Geo_Rate <- traitDependentBAMM(edata.sub, trait.vector.sub, 1000, return.full = FALSE, method = "mann-whitney", logrates = TRUE, two.tailed = TRUE, traitorder = NA)
      
      cat(paste0(clade,",", Tmean, ",", treatment, ",", Tmean.sub, ",", Corr_Geo_Rate$estimate$`1`, ",", Corr_Geo_Rate$estimate$`0`, ",", Corr_Geo_Rate$p.value, sep=""), file=file2, sep="\n", append = T)
    }
    
    
    ################################################
    
    #assoicate Mean Annual Tm
    #using Koeppen-Geiger tropical data to index temperate species in Mean Annual Tm data
    An_Tm.vector.sub <- An_Tm.vector[which((names(An_Tm.vector) %in% names(Trop.Koep.vector)))]
    
    trait.vector3 <-  treedata(tree, An_Tm.vector.sub)$data
    T.data <- cbind.data.frame(Species=row.names(trait.vector3), Tem=as.numeric(trait.vector3[,1]))
    K.data.Tem.species <- K.data %>% filter(Tropicality==0) %>% select(Species) 
    Temp.species <- intersect(as.character(K.data.Tem.species$Species), as.character(T.data$Species))
    
    #drop temperate species 10%, 30% and 50%
    for(i in c(0.1, 0.3, 0.5)){
      treatment <- paste0(i*100, "% drop")
      #drop temperate species 10%
      drop_tips3 <- as.data.frame(Temp.species) %>% sample_frac(as.numeric(i))
      keep.tips3 <- setdiff(T.data$Species, drop_tips3$Temp.species)
      
      edata.sub3 <- subtreeBAMM(edata, tips = keep.tips3)
      
      tip_rates.sub3 <- getTipRates(edata.sub3, returnNetDiv = FALSE, statistic = 'median')$lambda.avg
      Tmean.sub3 <- mean(tip_rates.sub3)
      
      trait.vector.sub3 <- trait.vector3[keep.tips3, ]
      
      Corr_An_Tm_Rate <- traitDependentBAMM(edata.sub3, trait.vector.sub3, 1000, return.full = FALSE, method = "spearman", logrates = TRUE, two.tailed = TRUE, traitorder = NA)
    
      cat(paste0(clade,",", Tmean, ",", treatment, ",", Tmean.sub3, ",", Corr_An_Tm_Rate$estimate, ",", Corr_An_Tm_Rate$p.value, sep=""), file=file3, sep="\n", append = T)
    }
    
  })
}



#prepare table file and headers
#Koep
file1 <- "./results/Rosid_temperate_species_drop_treatment_Koep.csv"
cat("Clade,Tip_rates,Treatment,Tip_rates%,Trop_rates%,Temp_rates%,P-value%\n", file=file1)

#Geo
file2 <- "./results/Rosid_temperate_species_drop_treatment_Geo.csv"
cat("Clade,Tip_rates,Treatment,Tip_rates%,Trop_rates%,Temp_rates%,P-value%\n", file=file2)

#Ann_Tm
file3 <- "./results/Rosid_temperate_species_drop_treatment_An_Tm.csv"
cat("Clade,Tip_rates,Treatment,Tip_rates%,Estimated_rates%,P-value%\n", file=file3)

# read in orders
Order <- read.csv("order.txt", header=F)
Order <- as.character(Order$V1)

#if run specific order
#clade <- Order[17]
strapp_drop_tip_test(clade)

#one run for all
for(i in 1:length(Order)){
  clade <- Order[i]
  print(clade)
  strapp_drop_tip_test(clade)
}


##########family-wise p-value adjustment#################

rm(list=ls())
library("tidyverse")

#read in p-value of ES-SIM test for each rosid order
files <- list.files("./results/", pattern = "^Rosid_temperate_species_drop_treatment_", full.names = T)

test <- read_csv(files[1], col_names = T)

# create a "dd" function to fo p.adjust
dd <- function(x){
  z <- p.adjust(x, method="hochberg")
}

essim.new <- essim %>% mutate(pv.adjust=dd(`P-value`))

#read in p-value of FiSSE from each order (binary traits)
#confirmed that p.adjust function handle the "NA" correctly

fisse.Koep <- read_csv(files[2], col_names = T)
fisse.Koep.new <- fisse.Koep %>% mutate(pv.adjust=dd(pval))


fisse.Geo <- read_csv(files[1], col_names = T)
fisse.Geo <- fisse.Geo[,-5]
fisse.Geo.new <- fisse.Geo %>% mutate(pv.adjust=dd(pval))

#read in p-value generated from STRAPP in BAMMtools
strapp <- read_csv(files[4], col_names = T)

strapp.new <- strapp %>% mutate(pv.adjust.mat=dd(Pmat), 
                                pv.adjust.koe=dd(Ptkoe),
                                pv.adjust.geo=dd(Ptgeo))

results <- cbind.data.frame(essim.new[,-2], fisse.Geo.new[,4:5], fisse.Koep.new[,4:5],
                            strapp.new[,2], strapp.new[,5], strapp.new[,3], strapp.new[,6],
                            strapp.new[,4], strapp.new[,7])

#name the header of table
names(results) <- c("Clade", "P.essim", "P.ess.adjust", "P.fis.geo", "P.fis.geo.adjust",
                    "P.fis.koep", "P.fis.koep.adjust", "P.str.mat", "P.str.mat.adjust", "P.str.koe", "P.str.koe.adjust",
                    "P.str.geo", "P.str.geo.adjust")

#output
write.csv(results, "New_test_data_rosids_17/rosid_17order_traist_pvalue_adjuest.csv", row.names=F, quote=F)

